package com.yunzhi.nanyang.common;

import com.yunzhi.nanyang.entity.SysUser;
import com.yunzhi.nanyang.entity.TaPerson;
import com.yunzhi.nanyang.service.ISysUserDataScopeService;
import com.yunzhi.nanyang.service.ISysUserService;
import com.yunzhi.nanyang.service.ITaPersonService;
import com.yunzhi.nanyang.shiro.realms.manager.ManagerRealm;
import com.yunzhi.nanyang.shiro.utils.JWTUtil;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.subject.Subject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.Collection;
import java.util.List;

@Component
public class BaseController {

    @Autowired
    ISysUserService iSysUserService;

    @Autowired
    ITaPersonService iTaPersonService;

    @Autowired
    ISysUserDataScopeService iSysUserDataScopeService;

    public String getLoginId() {
        Subject subject = SecurityUtils.getSubject();
        String token = subject.getPrincipal().toString();

//        List<Object> list = Arrays.asList(subject.getPrincipals().fromRealm("managerRealm").toArray());
//        String token = list.get(0).toString();

        return JWTUtil.getLoginId(token);
    }

    public SysUser currentUser() throws Exception {
        String loginId = getLoginId();
        if (StringUtils.isEmpty(loginId)) {
            throw new Exception("请先登录");
        }

        SysUser user = iSysUserService.getByLoginId(loginId);
        if (user == null || user.getStatus() == Constants.STATUS_DELETE) {
            throw new Exception("人员不存在");
        }

        return user;
    }

    public TaPerson currentPerson() throws Exception {
        String personId = getLoginId();
        if (StringUtils.isEmpty(personId)) {
            throw new Exception("请先登录");
        }

        TaPerson taPerson = iTaPersonService.getById(personId);
        if (taPerson == null || taPerson.getStatus() == Constants.STATUS_DELETE) {
            throw new Exception("人员不存在");
        }

        return taPerson;
    }

    public boolean checkOrgAccess(String orgId, String userId) {
        return iSysUserDataScopeService.checkOrgAccess(orgId, userId);
    }

    public List<String> getAccessOrgs(String userId) {
        return iSysUserDataScopeService.getAccessOrgs(userId);
    }
}
