package com.yunzhi.nanyang.common;

import cn.binarywang.wx.miniapp.api.WxMaService;
import cn.binarywang.wx.miniapp.api.impl.WxMaServiceImpl;
import cn.binarywang.wx.miniapp.config.impl.WxMaDefaultConfigImpl;
import com.yunzhi.nanyang.config.WeixinConfig;
import com.yunzhi.nanyang.entity.SysMiniapp;
import com.yunzhi.nanyang.service.ISysMiniappService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component
public class WxUtils {
    // 农机手小程序
    private static WxMaService workerService;
    // 农户小程序
    private static WxMaService farmerService;

    // 此处不能使用变量注入方式, 否则会是 null
    ISysMiniappService iSysMiniappService;

    @Autowired
    public WxUtils(ISysMiniappService iSysMiniappService) {
        this.iSysMiniappService = iSysMiniappService;

        try {
            setWorkerService();
            setFarmerService();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public WxMaService getWorkerService() throws Exception {
        if (workerService == null) {
            setWorkerService();
        }

        return workerService;
    }

    public WxMaService getFarmerService() throws Exception {
        if (farmerService == null) {
            setFarmerService();
        }

        return farmerService;
    }

    public WxMaService getService(String client) throws Exception {
        return Constants.CLIENT_WORKER.equals(client) ? getWorkerService() : getFarmerService();
    }

    private void setWorkerService() throws Exception {
        SysMiniapp sysMiniapp = iSysMiniappService.getByClient(Constants.CLIENT_WORKER);
        if (sysMiniapp == null) {
            throw new Exception("未找到农机手小程序配置");
        }

        workerService = initService(sysMiniapp);
    }

    private void setFarmerService() throws Exception {
        SysMiniapp sysMiniapp = iSysMiniappService.getByClient(Constants.CLIENT_FARMER);
        if (sysMiniapp == null) {
            throw new Exception("未找到农户小程序配置");
        }

        farmerService = initService(sysMiniapp);
    }

    private WxMaService initService(SysMiniapp sysMiniapp) {
        WxMaDefaultConfigImpl conf = new WxMaDefaultConfigImpl();
        conf.setAppid(sysMiniapp.getAppId());
        conf.setSecret(sysMiniapp.getSecret());
        conf.setToken(sysMiniapp.getToken());
        conf.setAesKey(sysMiniapp.getAesKey());
        conf.setMsgDataFormat("JSON");

        WxMaService service = new WxMaServiceImpl();
        service.setWxMaConfig(conf);
        return service;
    }
}
