package com.yunzhi.nanyang.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.nanyang.common.BaseController;
import com.yunzhi.nanyang.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.nanyang.service.ITaAccountService;
import com.yunzhi.nanyang.entity.TaAccount;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 账户表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-03-08
 */

@Api(tags = "账户表")
@RestController
@RequestMapping("/")
public class TaAccountController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaAccountController.class);

    @Autowired
    public ITaAccountService iTaAccountService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taAccount",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taAccountList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaAccount> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaAccount> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaAccount> result = iTaAccountService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taAccount 实体对象
     * @return
     */
    @RequestMapping(value="/taAccount",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taAccountAdd(@ApiParam("保存内容") @RequestBody TaAccount taAccount) throws Exception{

        if (iTaAccountService.save(taAccount)){
            return ResponseBean.success(taAccount);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taAccount/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taAccountDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaAccountService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taAccount 实体对象
     * @return
     */
    @RequestMapping(value="/taAccount/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taAccountUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaAccount taAccount) throws Exception{

        if (iTaAccountService.updateById(taAccount)){
            return ResponseBean.success(iTaAccountService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taAccount/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taAccountGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaAccountService.getById(id));
    }
}
