package com.yunzhi.nanyang.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.nanyang.common.BaseController;
import com.yunzhi.nanyang.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.nanyang.service.ITaAccountLogService;
import com.yunzhi.nanyang.entity.TaAccountLog;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 流水表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-03-08
 */

@Api(tags = "流水表")
@RestController
@RequestMapping("/")
public class TaAccountLogController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaAccountLogController.class);

    @Autowired
    public ITaAccountLogService iTaAccountLogService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taAccountLog",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taAccountLogList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaAccountLog> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaAccountLog> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaAccountLog> result = iTaAccountLogService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taAccountLog 实体对象
     * @return
     */
    @RequestMapping(value="/taAccountLog",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taAccountLogAdd(@ApiParam("保存内容") @RequestBody TaAccountLog taAccountLog) throws Exception{

        if (iTaAccountLogService.save(taAccountLog)){
            return ResponseBean.success(taAccountLog);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taAccountLog/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taAccountLogDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaAccountLogService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taAccountLog 实体对象
     * @return
     */
    @RequestMapping(value="/taAccountLog/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taAccountLogUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaAccountLog taAccountLog) throws Exception{

        if (iTaAccountLogService.updateById(taAccountLog)){
            return ResponseBean.success(iTaAccountLogService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taAccountLog/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taAccountLogGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaAccountLogService.getById(id));
    }
}
