package com.yunzhi.nanyang.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.nanyang.common.BaseController;
import com.yunzhi.nanyang.common.Constants;
import com.yunzhi.nanyang.common.ResponseBean;
import com.yunzhi.nanyang.common.StringUtils;
import com.yunzhi.nanyang.entity.SysUser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.nanyang.service.ITaMachineryService;
import com.yunzhi.nanyang.entity.TaMachinery;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 农机表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-03-08
 */

@Api(tags = "农机表")
@RestController
@RequestMapping("/")
public class TaMachineryController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaMachineryController.class);

    @Autowired
    public ITaMachineryService iTaMachineryService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/machinery",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taMachineryList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                        @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                        @ApiParam("名称") @RequestParam(value ="name", required = false) String name,
                                        @ApiParam("类型") @RequestParam(value ="typeId", required = false) String typeId) throws Exception{
        SysUser sysUser = currentUser();
        boolean isAdmin = Constants.ADMIN_ID.equals(sysUser.getUserId());

        IPage<TaMachinery> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaMachinery> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(name), "name", "%" + name + "%");
        queryWrapper.eq(!StringUtils.isEmpty(typeId), "type_id", typeId);
        queryWrapper.in(!isAdmin, "org_id", getAccessOrgs(sysUser.getUserId()));
        queryWrapper.gt("status", Constants.STATUS_DELETE);
        queryWrapper.orderByDesc("create_date");

        IPage<TaMachinery> result = iTaMachineryService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taMachinery 实体对象
     * @return
     */
    @RequestMapping(value="/admin/machinery",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    @RequiresPermissions("machinery:add")
    public ResponseBean taMachineryAdd(@ApiParam("保存内容") @RequestBody TaMachinery taMachinery) throws Exception{
        SysUser sysUser = currentUser();

        if (StringUtils.isEmpty(taMachinery.getOrgId())) {
            return ResponseBean.error("请设置农机归属");
        }

        if (!checkOrgAccess(taMachinery.getOrgId(), sysUser.getUserId())) {
            return ResponseBean.error("无权进行此操作");
        }

        taMachinery.setMachineryId(null);
        taMachinery.setCreateUser(sysUser.getUserId());

        if (iTaMachineryService.saveAll(taMachinery)){
            return ResponseBean.success(taMachinery);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/machinery/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    @RequiresPermissions("machinery:delete")
    public ResponseBean taMachineryDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        SysUser sysUser = currentUser();

        TaMachinery taMachinery = iTaMachineryService.getExistBy("machinery_id", id, false, true);
        if (null == taMachinery) {
            return ResponseBean.success("success");
        }

        if (!checkOrgAccess(taMachinery.getOrgId(), sysUser.getUserId())) {
            return ResponseBean.error("无权进行此操作");
        }

        if(iTaMachineryService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taMachinery 实体对象
     * @return
     */
    @RequestMapping(value="/admin/machinery/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    @RequiresPermissions("machinery:update")
    public ResponseBean taMachineryUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaMachinery taMachinery) throws Exception{
        SysUser sysUser = currentUser();

        if (StringUtils.isEmpty(taMachinery.getOrgId())) {
            return ResponseBean.error("请设置农机归属");
        }

        if (!checkOrgAccess(taMachinery.getOrgId(), sysUser.getUserId())) {
            return ResponseBean.error("无权进行此操作");
        }

        taMachinery.setMachineryId(id);

        if (iTaMachineryService.updateAll(taMachinery)){
            return ResponseBean.success(taMachinery);
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/machinery/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taMachineryGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaMachineryService.getDetail(id));
    }
}
