package com.yunzhi.nanyang.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.nanyang.common.BaseController;
import com.yunzhi.nanyang.common.ResponseBean;
import com.yunzhi.nanyang.common.SMSCaptcha;
import com.yunzhi.nanyang.common.StringUtils;
import com.yunzhi.nanyang.entity.SysUser;
import com.yunzhi.nanyang.service.ISysUserService;
import com.yunzhi.nanyang.vo.PhoneParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.nanyang.service.ITaPersonService;
import com.yunzhi.nanyang.entity.TaPerson;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 人员表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-03-08
 */

@Api(tags = "人员表")
@RestController
@RequestMapping("/")
public class TaPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPersonController.class);

    @Autowired
    public ITaPersonService iTaPersonService;

    @Autowired
    public ISysUserService iSysUserService;

    @Autowired
    public SMSCaptcha smsCaptcha;


//    /**
//     * 分页查询列表
//     * @param pageNum
//     * @param pageSize
//     * @return
//     */
//    @RequestMapping(value="/taPerson",method= RequestMethod.GET)
//    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taPersonList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
//									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{
//
//		    IPage<TaPerson> pg = new Page<>(pageNum, pageSize);
//            QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<>();
//            queryWrapper.orderByDesc("create_date");
//
//            IPage<TaPerson> result = iTaPersonService.page(pg, queryWrapper);
//            return ResponseBean.success(result);
//    }
//
//    /**
//     * 保存对象
//     * @param taPerson 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taPerson",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taPersonAdd(@ApiParam("保存内容") @RequestBody TaPerson taPerson) throws Exception{
//
//        if (iTaPersonService.save(taPerson)){
//            return ResponseBean.success(taPerson);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPerson/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taPersonDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaPersonService.removeById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
    /**
     * 修改对象
     * @param appid  实体ID
     * @param id  实体ID
     * @param phoneParam 实体对象
     * @return
     */
    @RequestMapping(value="/wx/{appid}/person/{id}/phone",method= RequestMethod.PUT)
    @ApiOperation(value="更新电话", notes = "更新电话", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taPersonUpdate(@ApiParam("小程序ID") @PathVariable String appid,
                                       @ApiParam("对象ID") @PathVariable String id,
                                       @ApiParam("更新内容") @RequestBody PhoneParam phoneParam) throws Exception{

        TaPerson taPerson = currentPerson();
        if (!id.equals(taPerson.getPersonId())) {
            return ResponseBean.error("待更新人员ID不正确");
        }

        if (StringUtils.isEmpty(phoneParam.getPhone())) {
            return ResponseBean.error("手机号码为空");
        }

        boolean isOk = smsCaptcha.validate(phoneParam.getPhone(), phoneParam.getCaptcha());
        if (!isOk) {
            return ResponseBean.error("验证码不正确或者已过期");
        }

        taPerson.setPhone(phoneParam.getPhone());

        // 关联系统人员
        SysUser sysUser = iSysUserService.getExistBy("phone", phoneParam.getPhone(), false, true);
        if (sysUser != null && StringUtils.isEmpty(taPerson.getUserId())) {
            taPerson.setUserId(sysUser.getUserId());
        }

        if (iTaPersonService.updateById(taPerson)){


            return ResponseBean.success(taPerson);
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPerson/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taPersonGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaPersonService.getById(id));
//    }
}
