package com.yunzhi.nanyang.service.impl;

import com.yunzhi.nanyang.common.Constants;
import com.yunzhi.nanyang.common.StringUtils;
import com.yunzhi.nanyang.entity.TaImages;
import com.yunzhi.nanyang.entity.TaMachinery;
import com.yunzhi.nanyang.entity.TaRegion;
import com.yunzhi.nanyang.entity.TdMachineryType;
import com.yunzhi.nanyang.mapper.TaImagesMapper;
import com.yunzhi.nanyang.mapper.TaMachineryMapper;
import com.yunzhi.nanyang.mapper.TaRegionMapper;
import com.yunzhi.nanyang.mapper.TdMachineryTypeMapper;
import com.yunzhi.nanyang.service.ITaMachineryService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.HashMap;
import java.util.List;

/**
 * <p>
 * 农机表 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2022-03-08
 */
@Service
public class TaMachineryServiceImpl extends BaseServiceImpl<TaMachineryMapper, TaMachinery> implements ITaMachineryService {

    @Autowired
    TaImagesMapper taImagesMapper;

    @Autowired
    TdMachineryTypeMapper tdMachineryTypeMapper;

    @Autowired
    TaRegionMapper taRegionMapper;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean saveAll(TaMachinery taMachinery) throws Exception {
        setRedundanceName(taMachinery);

        boolean isOk = save(taMachinery);
        if (!isOk) return false;

        // 图片保存失败不影响主记录
        try {
            saveImages(taMachinery);
        } catch (Exception e) {
            e.printStackTrace();
        }

        return true;
    }

    @Override
    public boolean updateAll(TaMachinery taMachinery) throws Exception {
        setRedundanceName(taMachinery);

        boolean isOk = updateById(taMachinery);
        if (!isOk) return false;

        // 图片保存失败不影响主记录
        try {
            saveImages(taMachinery);
        } catch (Exception e) {
            e.printStackTrace();
        }

        return true;
    }

    @Override
    public TaMachinery getDetail(String machineryId) {
        TaMachinery taMachinery = getExistBy("machinery_id", machineryId, false, true);
        if (null == taMachinery) return null;

        setRedundanceName(taMachinery);

        List<TaImages> images = taImagesMapper.getListBy(Constants.TARGET_MACHINERY, machineryId);
        taMachinery.setImages(images);

        return taMachinery;
    }

    private void saveImages(TaMachinery taMachinery) {
        String machineryId = taMachinery.getMachineryId();
        // 先删除所有
        taImagesMapper.deleteByMap(new HashMap<String, Object>(){{
            put("target_id", machineryId);
            put("target_type", Constants.TARGET_MACHINERY);
        }});

        List<TaImages> images = taMachinery.getImages();
        if (null != images && images.size() > 0) {
            for (TaImages image : images) {
                if (!StringUtils.isEmpty(image.getUrl())) {
                    image.setTargetId(machineryId);
                    image.setTargetType(Constants.TARGET_MACHINERY);
                    taImagesMapper.insert(image);
                }
            }
        }
    }

    private void setRedundanceName(TaMachinery taMachinery) {
        // 分类
        if (!StringUtils.isEmpty(taMachinery.getTypeId())) {
            TdMachineryType tdMachineryType = tdMachineryTypeMapper.selectById(taMachinery.getTypeId());
            if (null != tdMachineryType && tdMachineryType.getStatus() > Constants.STATUS_DELETE) {
                taMachinery.setTypeName(tdMachineryType.getName());
            } else {
                taMachinery.setTypeId(null);
                taMachinery.setTypeName(null);
            }
        }

        // 所属区域
        if (!StringUtils.isEmpty(taMachinery.getRegionId())) {
            TaRegion taRegion = taRegionMapper.selectById(taMachinery.getRegionId());
            if (null != taRegion && taRegion.getStatus() > Constants.STATUS_DELETE) {
                taMachinery.setRegionName(taRegion.getName());
            } else {
                taMachinery.setRegionId(null);
                taMachinery.setRegionName(null);
            }
        }
    }
}
