package com.yunzhi.nanyang.shiro.filters;

import com.yunzhi.nanyang.shiro.utils.JWTUtil;
import org.apache.shiro.authc.AuthenticationToken;
import org.apache.shiro.subject.Subject;
import org.apache.shiro.web.filter.authc.AuthenticatingFilter;
import org.apache.shiro.web.util.WebUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;

public abstract class JWTFilter extends AuthenticatingFilter {

    private Logger LOGGER = LoggerFactory.getLogger(this.getClass());

    public final static String JWT_HEADER = "Authorization";

    // 20 分钟刷新一次 token
    private final static long REFRESH_MILLS = 20 * 60 * 1000;

    private String unauthorizedUrl;
    public void setUnauthorizedUrl(String unauthorizedUrl) {
        this.unauthorizedUrl = unauthorizedUrl;
    }

    @Override
    protected boolean isAccessAllowed(ServletRequest request, ServletResponse response, Object mappedValue) {
        try {
            return executeLogin(request, response);
        } catch (Exception e) {
            response401(request, response, e);
        }

        return false;
    }

    @Override
    protected boolean onAccessDenied(ServletRequest servletRequest, ServletResponse servletResponse) throws Exception {
        return false;
    }

    @Override
    protected abstract AuthenticationToken createToken(ServletRequest servletRequest, ServletResponse servletResponse) throws Exception;

    // 主要用来刷新 token
    @Override
    protected boolean onLoginSuccess(AuthenticationToken token, Subject subject, ServletRequest request, ServletResponse response) throws Exception {
        String originToken = token.getPrincipal().toString();

        long diff = System.currentTimeMillis() - JWTUtil.getExpDate(originToken).getTime();
        if (diff >= REFRESH_MILLS) {
            HttpServletResponse httpServletResponse = WebUtils.toHttp(response);
            httpServletResponse.setHeader(JWT_HEADER, JWTUtil.refresh(originToken));
        }

        return true;
    }

    /**
     *Jump illegal request to / 401
     */
    protected void response401(ServletRequest request, ServletResponse response, Exception e) {
        String message = "";
        if (e != null) {
            try {
                message = URLEncoder.encode(e.getMessage(), "UTF-8");
            } catch (UnsupportedEncodingException ex) {
                //
            }
        }

        try {
            WebUtils.toHttp(response).sendRedirect(unauthorizedUrl + "?msg=" + message);
        } catch (IOException e1) {
            LOGGER.error(e1.getMessage());
        }
    }
}
