package com.yunzhi.nanyang.shiro.realms.manager;

import com.auth0.jwt.exceptions.JWTDecodeException;
import com.auth0.jwt.exceptions.TokenExpiredException;
import com.yunzhi.nanyang.shiro.utils.JWTToken;
import com.yunzhi.nanyang.shiro.utils.JWTUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authc.*;
import org.apache.shiro.authz.AuthorizationInfo;
import org.apache.shiro.authz.SimpleAuthorizationInfo;
import org.apache.shiro.realm.AuthorizingRealm;
import org.apache.shiro.subject.PrincipalCollection;

import java.util.Set;

@Slf4j
public class ManagerRealm extends AuthorizingRealm {

    IManagerService iManagerService;

    @Override
    public String getName() {
        return "managerRealm";
    }

    public void setManagerService(IManagerService iManagerService) {
        this.iManagerService = iManagerService;
    }

    @Override
    public boolean supports(AuthenticationToken token) {
        return token instanceof JWTToken;
    }

    @Override
    protected AuthorizationInfo doGetAuthorizationInfo(PrincipalCollection principalCollection) {
        // 获取用户角色，权限
        String token = (String) principalCollection.getPrimaryPrincipal();
        String loginId = JWTUtil.getLoginId(token);
        Set<String> roles = iManagerService.getRolesByLoginId(loginId);
        Set<String> permissions = iManagerService.getPermissionsLoginId(loginId);

        SimpleAuthorizationInfo simpleAuthorizationInfo = new SimpleAuthorizationInfo();
        simpleAuthorizationInfo.setStringPermissions(permissions);
        simpleAuthorizationInfo.setRoles(roles);
        return simpleAuthorizationInfo;
    }

    @Override
    protected AuthenticationInfo doGetAuthenticationInfo(AuthenticationToken authenticationToken) throws AuthenticationException {
        log.info("===========ManagerRealm===========");

        String token = (String) authenticationToken.getPrincipal();

        // 这里进行 token 验证, CredentialsMatcher 就不做了
        try {
            JWTUtil.verify(token);
        } catch (JWTDecodeException e1) {
            throw new AuthenticationException("非法的权限凭证");
        } catch (TokenExpiredException e2) {
            throw new ExpiredCredentialsException("授权过期, 请重新登录");
        } catch (Exception e) {
            e.printStackTrace();
            throw new AuthenticationException("凭证校验失败, 请重新登录");
        }


        String loginId = JWTUtil.getLoginId(token);

        if (!iManagerService.verify(loginId)) {
            throw new LockedAccountException("用户不存在或者状态异常");
        }

        // 交给 AuthenticatingRealm 使用 CredentialsMatcher 行校验
        return new SimpleAuthenticationInfo(token, token, getName());
    }
}
