package com.yunzhi.nanyang.shiro.realms.miniapp;

import com.auth0.jwt.exceptions.JWTDecodeException;
import com.auth0.jwt.exceptions.TokenExpiredException;
import com.yunzhi.nanyang.shiro.utils.JWTUtil;
import com.yunzhi.nanyang.shiro.utils.MiniappToken;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authc.*;
import org.apache.shiro.realm.AuthenticatingRealm;

@Slf4j
public class MiniappRealm extends AuthenticatingRealm {

    @Override
    public String getName() {
        return "miniappRealm";
    }

    @Override
    public boolean supports(AuthenticationToken token) {
        return token instanceof MiniappToken;
    }

    @Override
    protected AuthenticationInfo doGetAuthenticationInfo(AuthenticationToken authenticationToken) throws AuthenticationException {
        log.info("===========MiniappRealm===========");

        String token = (String) authenticationToken.getPrincipal();

        // 这里进行 token 验证, CredentialsMatcher 就不做了
        try {
            JWTUtil.verify(token);
        } catch (JWTDecodeException e1) {
            throw new AuthenticationException("非法的权限凭证");
        } catch (TokenExpiredException e2) {
            throw new ExpiredCredentialsException("授权过期, 请重新登录");
        } catch (Exception e) {
            e.printStackTrace();
            throw new AuthenticationException("凭证校验失败, 请重新登录");
        }
        // 交给 AuthenticatingRealm 使用 CredentialsMatcher 行校验
        return new SimpleAuthenticationInfo(token, token, getName());
    }
}
