package com.yunzhi.nanyang.shiro.utils;

import com.auth0.jwt.JWT;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.exceptions.JWTDecodeException;
import com.auth0.jwt.exceptions.JWTVerificationException;
import com.auth0.jwt.interfaces.DecodedJWT;
import com.auth0.jwt.interfaces.JWTVerifier;

import java.util.Date;

/**
 * 一个通用版本的 JWT
 */
public class JWTUtil {

    // 默认过期时间 1 小时
    private static final long EXPIRE_TIME = 60 * 60 * 1000;

    public static String getLoginId(String token) {
        try {
            DecodedJWT jwt = JWT.decode(token);
            return jwt.getSubject();
        } catch (JWTDecodeException e) {
            return null;
        }
    }

    public static Date getExpDate(String token) {
        try {
            DecodedJWT jwt = JWT.decode(token);
            return jwt.getExpiresAt();
        } catch (JWTDecodeException e) {
            return null;
        }
    }

    public static String sign(String loginId, String secret) {
        Date date = new Date(System.currentTimeMillis()+EXPIRE_TIME);
        Algorithm algorithm = Algorithm.HMAC256(secret);

        return JWT.create()
                .withSubject(loginId)
                .withExpiresAt(date)
                .withClaim("secret", secret)
                .sign(algorithm);
    }

    public static String refresh(String token) throws Exception {
        DecodedJWT jwt = JWT.decode(token);
        String loginId = jwt.getSubject();
        String secret = jwt.getClaim("secret").asString();

        return sign(loginId, secret);
    }

    public static void verify(String token) throws JWTVerificationException {
        DecodedJWT jwt = JWT.decode(token);
        String loginId = jwt.getSubject();
        String secret = jwt.getClaim("secret").asString();
        Algorithm algorithm = Algorithm.HMAC256(secret);
        JWTVerifier verifier = JWT.require(algorithm).withSubject(loginId).build();
        verifier.verify(jwt);
    }

}
